/***************************************************************************//**
 * @file
 * @brief       Define useful macros
 * @author:     npelling
 * @details This file contains useful C preprocessor macros used throughout the code.
 * @ingroup fbi_Includes
 ******************************************************************************/

#ifndef XMACROS_H_
#define XMACROS_H_

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/**
 * @addtogroup fbi_Includes
 *
 * @{
 */

/**
 * @name IsValid_Mac
 *
 * @details This template generates a [TYP]_IsValid() static inline function,
 * for validating whether the passed-down parameter is in the valid range
 * for type TYP.
 *
 * @{
 */

#define IsValid_Mac(TYP)      \
  inline static int32_t TYP ## _IsValid(TYP ## _Typ param)        \
  {                                     \
    return (param < (TYP ## _ToUpper_Mac(MAX)));      \
  }

/** @} */

/** @} */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* XMACROS_H_ */

/* End Of File ****************************************************************/
